@@ -12,7 +12,10 @@ itcl::class fvPreferences {
       method edit  { {page "fv"} }
       method close { }
       method raisePage { page }
+
       method _setGraphSize { menu {val ""} }
+      method _setGraphSizeX { menu {val ""} }
+
       method _askDirectorySetup {}
       method getCurrentGraphSize {} { return $fvPref::graphDispSize }
       method setNewGraphSize { size } { set ::fvPref::graphDispSize $size ; fvPref save }
@@ -155,7 +158,7 @@ itcl::body fvPreferences::edit { {page "fv"} } {
         .fvpref activate
         Notebook:raise [.fvpref childsite].notebook $page
         # since the notebook does not actual destroy, we need this line to update graph size
-        _setGraphSize [.fvpref childsite].notebook.f3.graphsize $fvPref::graphDispSize
+        _setGraphSize [.fvpref childsite].notebook.f3.graph.size $fvPref::graphDispSize
       } else {
         focus .fvpref
         raise .fvpref        
@@ -376,12 +379,12 @@ itcl::body fvPreferences::save {} {
    }
 
    if {$tcl_platform(platform) != "windows" } { 
-      if { [winfo exists .fvpref] && [winfo ismapped [.fvpref childsite].notebook.f3.graphsize] } {
-         _setGraphSize [.fvpref childsite].notebook.f3.graphsize $fvPref::graphDispSize
+      if { [winfo exists .fvpref] && [winfo ismapped [.fvpref childsite].notebook.f3.graph.size] } {
+         _setGraphSize [.fvpref childsite].notebook.f3.graph.size $fvPref::graphDispSize
       }
    } else {
-      if { [winfo exists .fvpref] && [winfo ismapped .fvpref.notebook.f3.graphsize] } {
-         _setGraphSize .fvpref.notebook.f3.graphsize $fvPref::graphDispSize
+      if { [winfo exists .fvpref] && [winfo ismapped .fvpref.notebook.f3.graph.size] } {
+         _setGraphSize .fvpref.notebook.f3.graph.size $fvPref::graphDispSize
       }
    }
 
@@ -732,26 +735,55 @@ itcl::body fvPreferences::_buildPage_Graphs { w } {
    }
 
    # Default graph display size
-   
-   ::iwidgets::optionmenu $w.graphsize -labeltext "Graph Size:" -labelpos w \
-         -command [itcl::code $this _setGraphSize $w.graphsize] -labelfont g_titleFont -font g_titleFont
 
-   set _graphDefaultWndw $w.graphsize
+   #
+   # 10/31/2020 - Pan Chai
+   #
+   # iwidgets optionmenu has been disabled on Mac due to incompatiablity issue with new Tcl/Tk
+   #
+
+#   ::iwidgets::optionmenu $w.graphsize -labeltext "Graph Size:" -labelpos w \
+#         -command [itcl::code $this _setGraphSize $w.graphsize] -labelfont g_titleFont -font g_titleFont
+#
+
+#   foreach dim $fvPref::GraphDefaultSizeList {
+#       $w.graphsize insert end $dim
+#   }
+#   $w.graphsize insert end "-----"
+#   $w.graphsize insert end "Configure.."
+#   $w.graphsize disable "-----"
+#   _setGraphSize $w.graphsize $fvPref::graphDispSize
+
+   frame $w.graph
+   menubutton $w.graph.size -menu $w.graph.size.menu -text "Graph Size" \
+              -relief raised -font g_titleFont
+   menu $w.graph.size.menu -tearoff 0
+
+   set _graphDefaultWndw $w.graph.size.menu
+
    foreach dim $fvPref::GraphDefaultSizeList {
-       $w.graphsize insert end $dim
+       $w.graph.size.menu add command -label $dim \
+       -command [itcl::code $this _setGraphSize $w.graph.size $dim]
    }
-   $w.graphsize insert end "-----"
-   $w.graphsize insert end "Configure.."
-   $w.graphsize disable "-----"
-   _setGraphSize $w.graphsize $fvPref::graphDispSize
+
+   $w.graph.size.menu add command -label "-----"
+   $w.graph.size.menu add command -label "Configure.." -command [itcl::code $this _setGraphSize $w.graph.size "configure"]
+
+   # $w.graph.size.menu disable "-----"
+   _setGraphSize $w.graph.size $fvPref::graphDispSize
+
+   label $w.graph.label -text "Graph Size: "
+   grid $w.graph.label -row 1  -column 1  -sticky w  -pady $_padYAmnt \
+         -padx $_padXAmnt
+   grid $w.graph.size  -row 1  -column 2  -sticky w  -pady $_padYAmnt \
+         -padx $_padXAmnt
 
    grid $w.auto       -row 1  -column 1  -sticky w  -pady $_padYAmnt \
          -padx $_padXAmnt
    grid $w.wcs        -row 2  -column 1  -sticky w  -pady $_padYAmnt \
          -padx $_padXAmnt
    grid $w.viewer     -row 3  -column 1  -sticky we -pady $_padYAmnt
-   grid $w.graphsize  -row 4  -column 1  -sticky w  -pady $_padYAmnt \
-         -padx $_padXAmnt
+   grid $w.graph      -row 4  -column 1  -sticky we -pady $_padYAmnt
 
    grid columnconfig $w 1 -weight 1
 }
@@ -857,10 +889,32 @@ itcl::body fvPreferences::_buildPage_Colors { w } {
 ##################
 
 itcl::body fvPreferences::_setGraphSize { menu {val ""} } {
+   if { $val != "" && $val == "configure" } {
+      set val [_getGraphSize]
+      _setGraphSize $menu $val
+   } else { 
+      # check to see if the format is "xlen ylen" instead of display "xlen X ylen"
+      set token [split $val " "]
+      if { [llength $token] >= 2 } {
+         $menu configure -text [format "%sX%s" [lindex $token 0] [lindex $token 1]]
+      } else {
+         $menu configure -text $val
+      }
+
+      set token [split $val "x"]
+      if { [llength $token] >= 2 } {
+         set fvPref::graphDispSize [format "%s %s" [lindex $token 0] [lindex $token 1]]
+      } else {
+         set fvPref::graphDispSize $val
+      }
+   }
+}
+
+itcl::body fvPreferences::_setGraphSizeX { menu {val ""} } {
    if { $val=="" } {
       # Update parameter for menu selection
 
-      set value [$menu get]
+      set value [$menu cget -label]
       if { $value=="Configure.." } {
          set val [_getGraphSize]
          _setGraphSize $menu $val
@@ -916,7 +970,9 @@ itcl::body fvPreferences::_addNewSize {} {
         }
     }
 
-    $_graphDefaultWndw select $newDim
+    # $_graphDefaultWndw select $newDim
+    _setGraphSize [winfo parent $_graphDefaultWndw] $newDim
+
     set entry {}
     lappend entry [$fa.wide get]
     lappend entry [$fa.hgte get]
@@ -977,12 +1033,18 @@ itcl::body fvPreferences::_deleteCheckedSize { {op "delete"} } {
     }
 
     for {set i [expr [llength $fvPref::GraphDefaultSizeList] - 1] } { $i >= 0 } {incr i -1 } {
-        $_graphDefaultWndw insert 0 [lindex $fvPref::GraphDefaultSizeList $i]
+        set dim [lindex $fvPref::GraphDefaultSizeList $i]
+        set parentWndw [winfo parent $_graphDefaultWndw]
+        $_graphDefaultWndw add command -label [lindex $fvPref::GraphDefaultSizeList $i] \
+                                       -command [itcl::code $this _setGraphSize $parentWndw $dim]
     }
 
-    $_graphDefaultWndw insert end "-----"
-    $_graphDefaultWndw insert end "Configure.."
-    $_graphDefaultWndw disable "-----"
+    $_graphDefaultWndw add command -label "-----"
+    $_graphDefaultWndw add command -label "Configure.." -command [itcl::code $this _setGraphSize $parentWndw "configure"]
+
+    # $_graphDefaultWndw insert end "-----"
+    # $_graphDefaultWndw insert end "Configure.."
+    # $_graphDefaultWndw disable "-----"
 
     set ::fvPref::graphDispSize $selectGraphSize
 
@@ -1016,12 +1078,10 @@ itcl::body fvPreferences::_deleteCheckedSize { {op "delete"} } {
              lappend entry $width
              lappend entry $height
              set ::fvPref::graphDispSize $entry
-             $_graphDefaultWndw select [lindex $fvPref::GraphDefaultSizeList 0]
+             _setGraphSize [winfo parent $_graphDefaultWndw] [lindex $fvPref::GraphDefaultSizeList 0]
           }
        }
     }
-
-  
 }
 
 itcl::body fvPreferences::_getGraphSize { } {
